import Flutter
import UIKit
import ZaloSDK

public class SwiftZaloSignInPlugin: NSObject, FlutterPlugin {
    
    public static func register(with registrar: FlutterPluginRegistrar) {
        
        let channel = FlutterMethodChannel(name: "com.yd.zalo/zalo_sign_in", binaryMessenger: registrar.messenger())
        let instance = SwiftZaloSignInPlugin()
        registrar.addMethodCallDelegate(instance, channel: channel)
    }
    
    public func handle(_ call: FlutterMethodCall, result: @escaping FlutterResult) {
        
        switch call.method {
            
        case "logIn":
            login(result: result)
            break
            
        default:
            result(FlutterMethodNotImplemented)
        }
    }
    
    func login(result: @escaping FlutterResult) {
        
        let parentController =  UIApplication.shared.keyWindow?.rootViewController as? UINavigationController;
        
        ZaloSDK.sharedInstance()?.authenticateZalo(with: ZAZAloSDKAuthenTypeViaZaloAppAndWebView , parentController: parentController, handler: { (response) in
            self.onAuthenticateComplete(with: response, result: result)
        })
    }
    
    
    func onAuthenticateComplete(with response: ZOOauthResponseObject?, result: @escaping FlutterResult) {
        
        if(response == nil || response?.isSucess == false) {
            result(self.getErrorResult(with: response))
        } else {
            result(self.getSuccesResult(with: response!))
        }
    }
    
    func getSuccesResult(with response: ZOOauthResponseObject) -> [String : Any]{
        return [
            "isSuccess" : true,
            "errorCode" : 0,
            "code" : response.oauthCode
        ]
    }
    
    func getErrorResult(with response: ZOOauthResponseObject?) -> [String : Any]{
        return [
            "isSuccess" : false,
            "errorCode" : response?.errorCode ?? -1001,
            "message" : response?.errorMessage ?? "Null ZOOauthResponseObject from native code(-1001)"
        ]
    }
}
